
:autogenerated:
..
    This file is autogenerated by `generate_custom_files` in conf.py,
    and ought to be generated via building the documentation through Sphinx, e.g.
    with `sphinx-build ./web ./build` from the root directory.

nltk.test package
=================

.. automodule:: nltk.test
    :members:
    :undoc-members:
    :show-inheritance:


***********
Subpackages
***********

    .. toctree::
       :maxdepth: 1

       nltk.test.unit


**********
Submodules
**********

    .. toctree::
       :maxdepth: 1

       nltk.test.all
       nltk.test.childes_fixt
       nltk.test.classify_fixt
       nltk.test.conftest
       nltk.test.discourse_fixt
       nltk.test.gensim_fixt
       nltk.test.gluesemantics_malt_fixt
       nltk.test.inference_fixt
       nltk.test.nonmonotonic_fixt
       nltk.test.portuguese_en_fixt
       nltk.test.probability_fixt